@@ -17,6 +17,7 @@ unname_vp <- function(x) {
 }
 #' @importFrom grid is.grob is.unit absolute.size
 #' @importFrom gtable is.gtable
+#' @importFrom farver set_channel get_channel
 unname_grob <- function(x) {
   if (is.gtable(x)) {
     x$name <- ''
@@ -32,6 +33,18 @@ unname_grob <- function(x) {
   }
   unit_elements <- vapply(x, is.unit, logical(1))
   x[unit_elements] <- lapply(.subset(x, unit_elements), absolute.size)
+  if (!is.null(x$gp)) {
+    if (is.character(x$gp$col)) x$gp$col <- set_channel(x$gp$col, "r", get_channel(x$gp$col, "r"))
+    if (is.character(x$gp$fill)) x$gp$fill <- set_channel(x$gp$fill, "r", get_channel(x$gp$fill, "r"))
+    if (is.numeric(x$gp$lty)) x$gp$lty <- c("blank", "solid", "dashed", "dotted", "dotdash", "longdash", "twodash")[x$gp$lty + 1]
+    if (is.character(x$gp$lty)) {
+      rename <- match(x$gp$lty, c("44", "13", "1343", "73", "2262"))
+      matched <- !is.na(rename)
+      x$gp$lty[matched] <- c("dashed", "dotted", "dotdash", "longdash", "twodash")[rename[matched]]
+    }
+    if (is.numeric(x$gp$lineend)) x$gp$lineend <- c("round", "butt", "square")[x$gp$lineend]
+    if (is.numeric(x$gp$linejoin)) x$gp$linejoin <- c("round", "mitre", "bevel")[x$gp$linejoin]
+  }
   x
 }
 collapse_guides <- function(guides) {
@@ -46,22 +59,22 @@ collapse_guides <- function(guides) {
   }
   guides
 }
+
 #' @importFrom gtable gtable_width gtable_height gtable gtable_add_grob
 #' @importFrom grid editGrob heightDetails widthDetails valid.just unit.c unit
-#' @importFrom ggplot2 margin element_grob element_blank
+#' @importFrom ggplot2 margin element_grob element_blank calc_element element_render
 guides_build <- function(guides, theme) {
-  legend.spacing <- theme$legend.spacing %||% unit(0.5, "lines")
-  legend.spacing.y <- theme$legend.spacing.y  %||% legend.spacing
-  legend.spacing.x <- theme$legend.spacing.x  %||% legend.spacing
-  legend.box.margin <- theme$legend.box.margin %||% margin()
+  legend.spacing.y <- calc_element(theme, "legend.spacing.y")
+  legend.spacing.x <- calc_element(theme, "legend.spacing.x")
+  legend.box.margin <- calc_element("legend.box.margin", theme) %||% margin()
 
   widths <- exec(unit.c, !!!lapply(guides, gtable_width))
   heights <- exec(unit.c, !!!lapply(guides, gtable_height))
 
-  just <- valid.just(theme$legend.box.just)
+  just <- valid.just(calc_element("legend.box.just", theme))
   xjust <- just[1]
   yjust <- just[2]
-  vert <- identical(theme$legend.box, "horizontal")
+  vert <- identical(calc_element("legend.box", theme), "horizontal")
   guides <- lapply(guides, function(g) {
     editGrob(g, vp = viewport(x = xjust, y = yjust, just = c(xjust, yjust),
                               height = if (vert) heightDetails(g) else 1,
@@ -98,19 +111,14 @@ guides_build <- function(guides, theme) {
 
   gtable_add_grob(
     guides,
-    element_grob(theme$legend.box.background %||% element_blank()),
+    element_render(theme, "legend.box.background"),
     t = 1, l = 1, b = -1, r = -1,
     z = -Inf, clip = "off", name = "legend.box.background"
   )
 }
-complete_guide_theme <- function(theme) {
-  position <- theme$legend.position %||% "right"
-  if (length(position) == 2) {
-    warning("Manual legend position not possible for collected guides. Defaulting to 'right'", call. = FALSE)
-    position <- "right"
-  }
-  theme$legend.position <- position
-  if (position %in% c("top", "bottom")) {
+#' @importFrom ggplot2 calc_element
+complete_guide_theme <- function(guide_pos, theme) {
+  if (guide_pos %in% c("top", "bottom")) {
     theme$legend.box <- theme$legend.box %||% "horizontal"
     theme$legend.direction <- theme$legend.direction %||% "horizontal"
     theme$legend.box.just <- theme$legend.box.just %||% c("center", "top")
@@ -121,28 +129,48 @@ complete_guide_theme <- function(theme) {
   }
   theme
 }
-#' @importFrom grid valid.just
-assemble_guides <- function(guides, theme) {
-  theme <- complete_guide_theme(theme)
+#' @importFrom utils getFromNamespace
+#' @importFrom ggplot2 calc_element
+assemble_guides <- function(guides, position, theme) {
+  # https://github.com/tidyverse/ggplot2/blob/57ba97fa04dadc6fd73db1904e39a09d57a4fcbe/R/guides-.R#L512
+  theme$legend.spacing <- theme$legend.spacing %||% unit(0.5, "lines")
+  theme$legend.spacing.y <- calc_element("legend.spacing.y", theme)
+  theme$legend.spacing.x <- calc_element("legend.spacing.x", theme)
+
+  # for every position, collect all individual guides and arrange them
+  # into a guide box which will be inserted into the main gtable
+  package_box <- try_fetch(
+    .subset2(getFromNamespace("Guides", "ggplot2"), "package_box"),
+    error = function(cnd) package_box
+  )
+  package_box(guides, position, theme)
+}
+
+#' @importFrom grid valid.just editGrob
+package_box <- function(guides, guide_pos, theme) {
+  theme <- complete_guide_theme(guide_pos, theme)
   guides <- guides_build(guides, theme)
 
   # Set the justification of the legend box
   # First value is xjust, second value is yjust
-  just <- valid.just(theme$legend.justification)
+  just <- valid.just(calc_element("legend.justification", theme))
   xjust <- just[1]
   yjust <- just[2]
-  guides <- grid::editGrob(guides, vp = viewport(x = xjust, y = yjust, just = c(xjust, yjust)))
+  guides <- editGrob(guides,
+    vp = viewport(x = xjust, y = yjust, just = c(xjust, yjust))
+  )
   guides <- gtable_add_rows(guides, unit(yjust, 'null'))
   guides <- gtable_add_rows(guides, unit(1 - yjust, 'null'), 0)
   guides <- gtable_add_cols(guides, unit(xjust, 'null'), 0)
   guides <- gtable_add_cols(guides, unit(1 - xjust, 'null'))
-
   guides
 }
+
+#' @importFrom ggplot2 calc_element find_panel
 #' @importFrom gtable gtable_width gtable_height
 #' @importFrom grid unit.c
-attach_guides <- function(table, guides, theme) {
-  guide_areas <- grepl('panel-guide_area', table$layout$name)
+attach_guides <- function(table, guides, position, theme) {
+  guide_areas <- grepl("panel-guide_area", table$layout$name)
   if (any(guide_areas)) {
     area_ind <- which(guide_areas)
     if (length(area_ind) != 1) {
@@ -152,14 +180,8 @@ attach_guides <- function(table, guides, theme) {
     return(table)
   }
   p_loc <- find_panel(table)
-  position <- theme$legend.position %||% "right"
-  if (length(position) == 2) {
-    warning('Manual position of collected guides not supported', call. = FALSE)
-    position <- "right"
-  }
-
-  spacing <- theme$legend.box.spacing %||% unit(0.2, 'cm')
-  legend_width  <- gtable_width(guides)
+  spacing <- calc_element("legend.box.spacing", theme) %||% unit(0.2, 'cm')
+  legend_width <- gtable_width(guides)
   legend_height <- gtable_height(guides)
   if (position == "left") {
     table <- gtable_add_grob(table, guides, clip = "off", t = p_loc$t,
